.. Copyright 2013-2018 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Module reahl.domain.systemaccountmodel
--------------------------------------

.. automodule:: reahl.domain.systemaccountmodel



AccountManagementInterface
""""""""""""""""""""""""""

.. autoclass:: AccountManagementInterface


LoginSession
""""""""""""

.. autoclass:: LoginSession
   :members:

SystemAccount
"""""""""""""

.. autoclass:: SystemAccount
   :members:

EmailAndPasswordSystemAccount
"""""""""""""""""""""""""""""

.. autoclass:: EmailAndPasswordSystemAccount
   :members: password_hash, email


PasswordException
"""""""""""""""""

.. autoexception:: PasswordException
   :members:
   
InvalidPasswordException
""""""""""""""""""""""""

.. autoexception:: InvalidPasswordException
   :members:
   
KeyException
""""""""""""

.. autoexception:: KeyException
   :members:

InvalidEmailException
"""""""""""""""""""""

.. autoexception:: InvalidEmailException
   :members:

NoSuchAccountException
""""""""""""""""""""""

.. autoexception:: NoSuchAccountException
   :members:

NotUniqueException
""""""""""""""""""

.. autoexception:: NotUniqueException
   :members:

AccountNotActiveException
"""""""""""""""""""""""""

.. autoexception:: AccountNotActiveException
   :members:



